.. :changelog:

History
-------

0.5.0 (2023-12-07)
++++++++++++++++++
* Add Django 5.0 compatibility
* Add Python 3.12 compatibility

0.4.0 (2022-12-21)
++++++++++++++++++

* Deprecate Django 3.1 compatibility
* Add option to not log contentful webhook invocations with the `LOG_CONTENTFUL_WEBHOOKS` setting

0.3.0 (2022-06-04)
++++++++++++++++++

* Add Django 4.0 compatibility

0.2.0 (2021-02-16)
++++++++++++++++++

* Change receiver url from hook/ to contentful-webhook/

0.1.0 (2021-02-15)
++++++++++++++++++

* First release on PyPI.
